@@ -14,7 +14,7 @@
 make_waterlines = function(heightmap,waterdepth=0,linecolor="grey40",zscale=1,alpha=1,linewidth=2,antialias = FALSE) {
   heightmap = heightmap/zscale
   na_matrix = is.na(heightmap)
-  heightlist = make_waterlines_cpp(heightmap,na_matrix,waterdepth)
+  heightlist = make_waterlines_cpp(heightmap,na_matrix,waterdepth/zscale)
   if(length(heightlist) > 0) {
     segmentlist = do.call(rbind,heightlist)
     segmentlist[,1] = segmentlist[,1] - nrow(heightmap)/2
