@@ -35,22 +35,20 @@
 #'@return Displays snapshot of current rgl plot (or saves to disk).
 #'@export
 #'@examples
-#'\dontrun{
+#'if(interactive()) {
+#'\donttest{
 #'montereybay %>%
 #'  sphere_shade() %>%
 #'  plot_3d(montereybay,zscale=50,zoom=0.6,theta=-90,phi=30)
 #'}
 #'  
-#'\dontrun{
+#'\donttest{
 #'render_snapshot()
 #'}
-#'
-#'\dontrun{
-#'}
 #'  
 #'#Create a title, but also pass the `gravity` argument to magick::image_annotate using ...
 #'#to center the text.
-#'\dontrun{
+#'\donttest{
 #'render_snapshot(title_text = "Monterey Bay, California", 
 #'                title_color = "white", title_bar_color = "black",
 #'                title_font = "Helvetica", gravity = "North")
@@ -63,6 +61,7 @@
 #'                title_font = "Helvetica", gravity = "North")
 #'rgl::rgl.close() 
 #'}
+#'}
 render_snapshot = function(filename, clear=FALSE, 
                            title_text = NULL, title_offset = c(20,20), 
                            title_color = "black", title_size = 30, title_font = "sans",
@@ -100,6 +99,9 @@ render_snapshot = function(filename, clear=FALSE,
   }
   temp = tempfile(fileext = ".png")
   if("webshot" %in% names(formals(rgl::snapshot3d))) {
+    if(!rgl::rgl.useNULL()) {
+      webshot = FALSE
+    }
     if(webshot) {
       rgl::snapshot3d(filename = temp, webshot = webshot, width = width, height = height)
     } else {
